@@ -3,9 +3,9 @@ from __future__ import annotations
 
 import re
 import sys
-from typing import List, Dict, Any, TYPE_CHECKING
+from typing import Any, TYPE_CHECKING
 
-from lark import Transformer
+from lark import Transformer, Token
 from lark.visitors import v_args
 
 if TYPE_CHECKING:
@@ -23,14 +23,14 @@ TWO_BLOCK_LABEL_TYPES = {"data", "resource"}
 
 
 # pylint: disable=missing-docstring,unused-argument
-class DictTransformer(Transformer):
-    def float_lit(self, args: List) -> float:
+class DictTransformer(Transformer[Token, "dict[str, list[dict[str, Any]]]"]):
+    def float_lit(self, args: list) -> float:
         return float("".join([str(arg) for arg in args]))
 
-    def int_lit(self, args: List) -> int:
+    def int_lit(self, args: list) -> int:
         return int("".join([str(arg) for arg in args]))
 
-    def expr_term(self, args: List) -> Any:
+    def expr_term(self, args: list) -> Any:
         args = self.strip_new_line_tokens(args)
 
         #
@@ -47,27 +47,27 @@ class DictTransformer(Transformer):
         # otherwise return the value itself
         return args[0]
 
-    def index_expr_term(self, args: List) -> str:
+    def index_expr_term(self, args: list) -> str:
         args = self.strip_new_line_tokens(args)
         return f"{str(args[0])}{str(args[1])}"
 
-    def index(self, args: List) -> str:
+    def index(self, args: list) -> str:
         args = self.strip_new_line_tokens(args)
         return f"[{str(args[0])}]"
 
-    def get_attr_expr_term(self, args: List) -> str:
+    def get_attr_expr_term(self, args: list) -> str:
         return f"{str(args[0])}.{str(args[1])}"
 
-    def attr_splat_expr_term(self, args: List) -> str:
+    def attr_splat_expr_term(self, args: list) -> str:
         return f"{args[0]}.*.{args[1]}"
 
-    def full_splat_expr_term(self, args: List) -> str:
+    def full_splat_expr_term(self, args: list) -> str:
         return f"{args[0]}[*].{args[1]}"
 
-    def tuple(self, args: List) -> List:
+    def tuple(self, args: list) -> list:
         return [self.to_string_dollar(arg) for arg in self.strip_new_line_tokens(args)]
 
-    def object_elem(self, args: List) -> Dict:
+    def object_elem(self, args: list) -> dict[str, Any]:
         # This returns a dict with a single key/value pair to make it easier to merge these
         # into a bigger dict that is returned by the "object" function
         key = self.strip_quotes(args[0])
@@ -77,25 +77,25 @@ class DictTransformer(Transformer):
             key: value,
         }
 
-    def object(self, args: List) -> Dict:
+    def object(self, args: list) -> dict:
         args = self.strip_new_line_tokens(args)
-        result: Dict[str, Any] = {}
+        result: dict[str, Any] = {}
         for arg in args:
             result.update(arg)
         return result
 
-    def function_call(self, args: List) -> str:
+    def function_call(self, args: list) -> str:
         args = self.strip_new_line_tokens(args)
         args_str = ""
         if len(args) > 1:
             args_str = ",".join([str(arg) for arg in args[1]])
         return f"{str(args[0])}({args_str})"
 
-    def arguments(self, args: List) -> List:
+    def arguments(self, args: list) -> list:
         return args
 
     @v_args(meta=True)
-    def block(self, meta: Meta, args: List) -> Dict:
+    def block(self, meta: Meta, args: list) -> dict[str, Any]:
         args = self.strip_new_line_tokens(args)
 
         # if the last token is a string instead of an object then the block is empty
@@ -104,7 +104,7 @@ class DictTransformer(Transformer):
         if isinstance(args[-1], str):
             args.append({})
 
-        result: Dict[str, Any] = {}
+        result: dict[str, Any] = {}
         current_level = result
         for arg in args[0:-2]:
             current_level[self.strip_quotes(arg)] = {}
@@ -129,7 +129,7 @@ class DictTransformer(Transformer):
 
         return result
 
-    def attribute(self, args: List) -> Dict:
+    def attribute(self, args: list) -> dict[str, Any]:
         key = str(args[0])
         if key.startswith('"') and key.endswith('"'):
             key = key[1:-1]
@@ -139,28 +139,28 @@ class DictTransformer(Transformer):
             key: value,
         }
 
-    def conditional(self, args: List) -> str:
+    def conditional(self, args: list) -> str:
         args = self.strip_new_line_tokens(args)
         return f"{args[0]} ? {args[1]} : {args[2]}"
 
-    def binary_op(self, args: List) -> str:
+    def binary_op(self, args: list) -> str:
         return " ".join([str(arg) for arg in args])
 
-    def unary_op(self, args: List) -> str:
+    def unary_op(self, args: list) -> str:
         return "".join([str(arg) for arg in args])
 
-    def binary_term(self, args: List) -> str:
+    def binary_term(self, args: list) -> str:
         args = self.strip_new_line_tokens(args)
         return " ".join([str(arg) for arg in args])
 
-    def body(self, args: List) -> Dict[str, List]:
+    def body(self, args: list) -> dict[str, list]:
         # A body can have multiple attributes with the same name
         # For example multiple Statement attributes in a IAM resource body
         # So This returns a dict of attribute names to lists
         # The attribute values will always be lists even if they aren't repeated
         # and only contain a single entry
         args = self.strip_new_line_tokens(args)
-        result: Dict[str, Any] = {}
+        result: dict[str, Any] = {}
         for arg in args:
             for key, value in arg.items():
                 key = str(key)
@@ -177,20 +177,20 @@ class DictTransformer(Transformer):
 
         return result
 
-    def start(self, args: List) -> Dict:
+    def start(self, args: list) -> dict[str, list[dict[str, Any]]]:
         args = self.strip_new_line_tokens(args)
         return args[0]
 
-    def binary_operator(self, args: List) -> str:
+    def binary_operator(self, args: list) -> str:
         return str(args[0])
 
-    def heredoc_template(self, args: List) -> str:
+    def heredoc_template(self, args: list) -> str:
         match = HEREDOC_PATTERN.match(str(args[0]))
         if not match:
             raise RuntimeError(f"Invalid Heredoc token: {args[0]}")
         return f'"{match.group(2)}"'
 
-    def heredoc_template_trim(self, args: List) -> str:
+    def heredoc_template_trim(self, args: list) -> str:
         # See https://github.com/hashicorp/hcl2/blob/master/hcl/hclsyntax/spec.md#template-expressions
         # This is a special version of heredocs that are declared with "<<-"
         # This will calculate the minimum number of leading spaces in each line of a heredoc
@@ -213,25 +213,25 @@ class DictTransformer(Transformer):
 
         return '"{}"'.format("\n".join(lines))
 
-    def for_tuple_expr(self, args: List) -> str:
+    def for_tuple_expr(self, args: list) -> str:
         args = self.strip_new_line_tokens(args)
         for_expr = " ".join([str(arg) for arg in args[1:-1]])
         return f"[{for_expr}]"
 
-    def for_intro(self, args: List) -> str:
+    def for_intro(self, args: list) -> str:
         args = self.strip_new_line_tokens(args)
         return " ".join([str(arg) for arg in args])
 
-    def for_cond(self, args: List) -> str:
+    def for_cond(self, args: list) -> str:
         args = self.strip_new_line_tokens(args)
         return " ".join([str(arg) for arg in args])
 
-    def for_object_expr(self, args: List) -> str:
+    def for_object_expr(self, args: list) -> str:
         args = self.strip_new_line_tokens(args)
         for_expr = " ".join([str(arg) for arg in args[1:-1]])
         return f"{{{for_expr}}}"
 
-    def strip_new_line_tokens(self, args: List) -> List:
+    def strip_new_line_tokens(self, args: list[Any]) -> list[Any]:
         """
         Remove new line and Discard tokens.
         The parser will sometimes include these in the tree so we need to strip them out here
